#include <gio/gio.h>

#if defined (__ELF__) && ( __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 6))
# define SECTION __attribute__ ((section (".gresource.gcm"), aligned (8)))
#else
# define SECTION
#endif

static const SECTION union { const guint8 data[4352]; const double alignment; void * const ptr;}  gcm_resource_data = { {
  0x47, 0x56, 0x61, 0x72, 0x69, 0x61, 0x6e, 0x74, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x18, 0x00, 0x00, 0x00, 0xac, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x28, 0x05, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 
  0x02, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 
  0x05, 0x00, 0x00, 0x00, 0xd4, 0xb5, 0x02, 0x00, 
  0xff, 0xff, 0xff, 0xff, 0xac, 0x00, 0x00, 0x00, 
  0x01, 0x00, 0x4c, 0x00, 0xb0, 0x00, 0x00, 0x00, 
  0xb4, 0x00, 0x00, 0x00, 0x4b, 0x50, 0x90, 0x0b, 
  0x00, 0x00, 0x00, 0x00, 0xb4, 0x00, 0x00, 0x00, 
  0x04, 0x00, 0x4c, 0x00, 0xb8, 0x00, 0x00, 0x00, 
  0xbc, 0x00, 0x00, 0x00, 0xf4, 0x3c, 0xaf, 0x8f, 
  0x03, 0x00, 0x00, 0x00, 0xbc, 0x00, 0x00, 0x00, 
  0x0d, 0x00, 0x76, 0x00, 0xd0, 0x00, 0x00, 0x00, 
  0xdf, 0x10, 0x00, 0x00, 0x66, 0xec, 0xb7, 0xce, 
  0x04, 0x00, 0x00, 0x00, 0xdf, 0x10, 0x00, 0x00, 
  0x0e, 0x00, 0x4c, 0x00, 0xf0, 0x10, 0x00, 0x00, 
  0xf4, 0x10, 0x00, 0x00, 0xb0, 0xb7, 0x24, 0x30, 
  0x01, 0x00, 0x00, 0x00, 0xf4, 0x10, 0x00, 0x00, 
  0x06, 0x00, 0x4c, 0x00, 0xfc, 0x10, 0x00, 0x00, 
  0x00, 0x11, 0x00, 0x00, 0x2f, 0x00, 0x00, 0x00, 
  0x01, 0x00, 0x00, 0x00, 0x6f, 0x72, 0x67, 0x2f, 
  0x04, 0x00, 0x00, 0x00, 0x67, 0x63, 0x6d, 0x2d, 
  0x70, 0x69, 0x63, 0x6b, 0x65, 0x72, 0x2e, 0x75, 
  0x69, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0xd9, 0x4f, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 
  0x78, 0xda, 0xed, 0x5c, 0x59, 0x73, 0xdb, 0x38, 
  0x12, 0x7e, 0xd7, 0xaf, 0xe8, 0xe5, 0x53, 0x52, 
  0x6b, 0xd9, 0x92, 0x9d, 0x64, 0x8e, 0xd8, 0x9a, 
  0x95, 0x3d, 0xb6, 0xe3, 0xaa, 0xf8, 0x28, 0x59, 
  0xae, 0x8c, 0xf7, 0x85, 0x05, 0x91, 0x2d, 0x11, 
  0x6b, 0x90, 0xe0, 0x00, 0xa0, 0x65, 0xed, 0xaf, 
  0xdf, 0x06, 0x49, 0x49, 0x4e, 0x44, 0xea, 0xa0, 
  0x9d, 0x99, 0x68, 0x8b, 0x2f, 0x2a, 0x52, 0xec, 
  0x06, 0xd1, 0xc7, 0xd7, 0x0d, 0x36, 0x8e, 0xc3, 
  0xdf, 0x9e, 0x42, 0x01, 0x8f, 0xa8, 0x34, 0x97, 
  0xd1, 0x91, 0xd3, 0xde, 0x6d, 0x39, 0x80, 0x91, 
  0x27, 0x7d, 0x1e, 0x8d, 0x8e, 0x9c, 0xbb, 0xfe, 
  0x59, 0xf3, 0x67, 0xe7, 0xb7, 0x4e, 0xe3, 0xf0, 
  0x1f, 0xcd, 0x26, 0x9c, 0x63, 0x84, 0x8a, 0x19, 
  0xf4, 0x61, 0xcc, 0x4d, 0x00, 0x23, 0xc1, 0x7c, 
  0x84, 0x83, 0xdd, 0xf6, 0x87, 0xdd, 0x16, 0xc8, 
  0x08, 0xfa, 0x09, 0xc2, 0xb5, 0x67, 0x00, 0x7e, 
  0x86, 0xf6, 0xbb, 0x5f, 0x5b, 0x1f, 0x7e, 0x7d, 
  0xf7, 0x0b, 0xec, 0xb7, 0xda, 0x07, 0xd0, 0x68, 
  0x9c, 0x5f, 0x5d, 0x5f, 0x9e, 0xc2, 0x89, 0x14, 
  0x52, 0xc1, 0x25, 0x8b, 0xd8, 0x08, 0x55, 0xe3, 
  0x44, 0xc6, 0x13, 0xc5, 0x47, 0x81, 0x81, 0x37, 
  0x27, 0x6f, 0x2d, 0x61, 0xbb, 0x99, 0x52, 0xf7, 
  0xb8, 0x17, 0x30, 0xe5, 0xc3, 0xa7, 0x64, 0x14, 
  0xa0, 0x86, 0x43, 0x95, 0xdd, 0xff, 0x2b, 0xa0, 
  0x7b, 0xcd, 0x71, 0xd7, 0x93, 0x61, 0xa7, 0xd1, 
  0xe8, 0x07, 0x5c, 0x43, 0xac, 0xe4, 0x48, 0xb1, 
  0x10, 0xe8, 0x72, 0xa8, 0x10, 0x41, 0xcb, 0xa1, 
  0x19, 0x33, 0x85, 0x1f, 0x61, 0x22, 0x13, 0xf0, 
  0x58, 0x04, 0x0a, 0x7d, 0xae, 0x8d, 0xe2, 0x83, 
  0xc4, 0x20, 0x70, 0x03, 0x2c, 0xf2, 0xf7, 0xa4, 
  0x6a, 0x84, 0x24, 0xdf, 0x70, 0x62, 0xff, 0x48, 
  0x22, 0x1f, 0x15, 0x98, 0x00, 0xc1, 0xa0, 0x0a, 
  0x35, 0xc8, 0x61, 0x7a, 0x73, 0x7e, 0x75, 0x97, 
  0x8b, 0x2b, 0xe0, 0x26, 0x19, 0x08, 0xee, 0xc1, 
  0x67, 0xee, 0x61, 0xa4, 0xb1, 0xc1, 0xe8, 0xbd, 
  0xf6, 0x1f, 0x1d, 0x90, 0x22, 0x06, 0x93, 0x94, 
  0xfc, 0xcc, 0xbe, 0xfd, 0x36, 0x7f, 0x3b, 0x9c, 
  0x49, 0x6a, 0x95, 0x19, 0x52, 0xe8, 0x47, 0x40, 
  0xd2, 0x14, 0xbd, 0x20, 0x57, 0x30, 0xec, 0x37, 
  0xf2, 0x17, 0xe4, 0xad, 0xed, 0x00, 0x69, 0xe4, 
  0x0d, 0x33, 0xb6, 0xc3, 0x0a, 0x64, 0x6c, 0x99, 
  0xde, 0x52, 0x2f, 0x27, 0x20, 0x48, 0xd1, 0x33, 
  0xbe, 0xdd, 0x45, 0x81, 0xe7, 0x72, 0xf9, 0xc0, 
  0xa3, 0xb4, 0xcd, 0x40, 0xc6, 0x24, 0x46, 0x40, 
  0xad, 0x91, 0x60, 0x63, 0x2e, 0x04, 0x0c, 0x10, 
  0x12, 0x8d, 0xc3, 0x44, 0xec, 0x34, 0x88, 0x12, 
  0xbe, 0x5c, 0xf4, 0x3f, 0x5d, 0xdf, 0xf5, 0xa1, 
  0x7b, 0x75, 0x0f, 0x5f, 0xba, 0xbd, 0x5e, 0xf7, 
  0xaa, 0x7f, 0xff, 0x31, 0x35, 0xa6, 0xa4, 0xa7, 
  0xf8, 0x88, 0x59, 0x3b, 0x3c, 0x8c, 0x05, 0xb7, 
  0x56, 0x66, 0x4a, 0xb1, 0xc8, 0x4c, 0x48, 0x29, 
  0x8d, 0xcb, 0xd3, 0xde, 0xc9, 0x27, 0xa2, 0xef, 
  0x1e, 0x5f, 0x7c, 0xbe, 0xe8, 0xdf, 0xdb, 0x6e, 
  0x9f, 0x5d, 0xf4, 0xaf, 0x4e, 0x6f, 0x6f, 0xe1, 
  0xec, 0xba, 0x07, 0x5d, 0xb8, 0xe9, 0xf6, 0xfa, 
  0x17, 0x27, 0x77, 0x9f, 0xbb, 0x3d, 0xb8, 0xb9, 
  0xeb, 0xdd, 0x5c, 0xdf, 0x9e, 0xee, 0x02, 0xdc, 
  0xa2, 0xed, 0x10, 0x36, 0xca, 0xd5, 0x09, 0x43, 
  0x6a, 0x29, 0x94, 0xa4, 0x35, 0x1f, 0x0d, 0xe3, 
  0x42, 0x93, 0xa8, 0xf7, 0x64, 0x3c, 0x4d, 0x5d, 
  0x12, 0x3e, 0x04, 0xec, 0x11, 0xc9, 0x88, 0x1e, 
  0xf2, 0x47, 0xea, 0x10, 0x03, 0x8f, 0x9c, 0x66, 
  0x1d, 0x1b, 0x09, 0x19, 0x8d, 0x32, 0x2f, 0x35, 
  0xcf, 0xf4, 0xf6, 0x11, 0xf8, 0x10, 0x22, 0x69, 
  0x76, 0x60, 0xac, 0x38, 0x39, 0x84, 0x91, 0x8b, 
  0xd6, 0x6b, 0xcc, 0xad, 0xb7, 0x03, 0x17, 0x91, 
  0xb7, 0xbb, 0x03, 0xef, 0xdb, 0x44, 0xc2, 0xa2, 
  0x07, 0x41, 0x7a, 0xbe, 0x35, 0x44, 0x4c, 0x0d, 
  0x9c, 0xf1, 0x21, 0x35, 0x7e, 0x26, 0xa4, 0x54, 
  0x3b, 0x70, 0x2c, 0xb5, 0xb1, 0xe4, 0x97, 0x5d, 
  0x80, 0xd6, 0x7e, 0xbb, 0xdd, 0x6a, 0xb6, 0x0f, 
  0x5a, 0xed, 0x1d, 0xb8, 0xbb, 0xed, 0x92, 0x38, 
  0xcd, 0x26, 0xe1, 0x87, 0x47, 0x64, 0xce, 0x21, 
  0xf3, 0xb0, 0xd3, 0x00, 0x48, 0xd1, 0x34, 0xfb, 
  0xa7, 0xa9, 0xf0, 0xcf, 0x84, 0x2b, 0xf2, 0xf5, 
  0x91, 0x79, 0xf8, 0xa7, 0x05, 0x54, 0x0b, 0x2c, 
  0x0f, 0xd1, 0xc9, 0xc1, 0x7f, 0x90, 0x10, 0xe5, 
  0x09, 0xa6, 0xf5, 0x91, 0x73, 0x6e, 0x1e, 0x7e, 
  0xe7, 0x24, 0xda, 0xc8, 0x01, 0xee, 0x1f, 0x39, 
  0x7e, 0x7a, 0xed, 0xc6, 0xdc, 0x7b, 0x40, 0xe5, 
  0x58, 0x7a, 0xe2, 0x20, 0x49, 0x63, 0x54, 0x64, 
  0xb3, 0x88, 0x85, 0x78, 0xe4, 0x10, 0x06, 0xdc, 
  0xa1, 0xf4, 0x12, 0xed, 0x74, 0xce, 0x98, 0xd0, 
  0x78, 0xb8, 0x37, 0x25, 0x28, 0xa6, 0x1f, 0x48, 
  0x45, 0x78, 0x70, 0xc7, 0xdc, 0x37, 0x81, 0xd3, 
  0x79, 0xbf, 0x8a, 0xdc, 0x70, 0x23, 0xd0, 0x01, 
  0x43, 0xda, 0xd1, 0xe4, 0xb0, 0x6c, 0x20, 0xe8, 
  0xcf, 0x09, 0x6a, 0x87, 0x0c, 0x15, 0x86, 0x18, 
  0x19, 0xea, 0xf5, 0x17, 0x1e, 0xf9, 0x72, 0x0c, 
  0x29, 0x29, 0x29, 0x9e, 0xd0, 0x90, 0xfa, 0x84, 
  0x75, 0x4c, 0x95, 0x62, 0xd4, 0x0a, 0x00, 0x3a, 
  0x96, 0x24, 0xa7, 0x0d, 0x10, 0x9a, 0x9e, 0x50, 
  0xf0, 0x21, 0x63, 0x87, 0xc8, 0x74, 0xa2, 0xec, 
  0xb5, 0x8f, 0x8f, 0x64, 0x59, 0xa7, 0x93, 0x45, 
  0x90, 0x9b, 0x54, 0xe2, 0x55, 0x7d, 0xe3, 0x9e, 
  0x8c, 0x5c, 0x7b, 0xe9, 0x74, 0x46, 0x91, 0x0c, 
  0xb1, 0x99, 0xb6, 0xde, 0x0c, 0xb3, 0xf0, 0xb3, 
  0x52, 0xb2, 0x49, 0x8c, 0x6e, 0x40, 0x36, 0x72, 
  0x3a, 0x99, 0x9e, 0x17, 0x18, 0xbc, 0x80, 0x0b, 
  0x3f, 0xb3, 0x62, 0xc4, 0x44, 0x33, 0xbd, 0x3d, 
  0x72, 0x1e, 0x07, 0xf2, 0x29, 0xb7, 0x45, 0x91, 
  0xfd, 0x8e, 0xe9, 0xe9, 0x33, 0xe3, 0x35, 0x2d, 
  0x79, 0x7b, 0x46, 0xbf, 0xd8, 0x8d, 0x47, 0xae, 
  0x39, 0x29, 0xd5, 0xe9, 0xf4, 0x55, 0xb2, 0x60, 
  0xbc, 0x2a, 0x06, 0x2f, 0xe2, 0x91, 0x8a, 0x93, 
  0xa9, 0x52, 0x97, 0x77, 0x3a, 0x14, 0x71, 0x0c, 
  0xf7, 0x98, 0x58, 0x87, 0x51, 0xc7, 0xcc, 0x23, 
  0xf3, 0x38, 0x9d, 0xfd, 0x42, 0xea, 0x54, 0x25, 
  0xf3, 0xfb, 0xa5, 0xfa, 0xf8, 0x46, 0x0f, 0x95, 
  0x74, 0x51, 0x55, 0x1f, 0x45, 0x7c, 0x21, 0x53, 
  0x23, 0x1e, 0xb9, 0x02, 0x87, 0xe4, 0x01, 0x1f, 
  0x36, 0xe4, 0x4a, 0xd3, 0xda, 0xe6, 0x6c, 0x46, 
  0xc6, 0x1b, 0x30, 0xad, 0x6d, 0xb5, 0xa5, 0x96, 
  0xfb, 0xa5, 0x94, 0x63, 0xc1, 0x7a, 0xab, 0x2d, 
  0xb8, 0xef, 0x7c, 0x4b, 0x5f, 0xd1, 0x8a, 0x2f, 
  0xb1, 0xe4, 0x72, 0x47, 0x7d, 0xb7, 0x94, 0xad, 
  0x50, 0xe6, 0x62, 0xb9, 0x2f, 0x42, 0x0a, 0x23, 
  0x99, 0xe4, 0xdc, 0x5e, 0xba, 0xb1, 0xa2, 0x20, 
  0x85, 0x63, 0xa7, 0x88, 0xfd, 0x05, 0x6a, 0x78, 
  0xa9, 0x2a, 0x88, 0x7b, 0x2f, 0xeb, 0x7c, 0xe1, 
  0x33, 0x52, 0xcc, 0x03, 0x69, 0x66, 0xbd, 0xf7, 
  0xe2, 0x53, 0x4c, 0x03, 0xa8, 0x6a, 0x7d, 0x1e, 
  0xd2, 0x78, 0xa4, 0x1a, 0x67, 0x2c, 0x35, 0xcf, 
  0xbc, 0xbc, 0xb5, 0x4a, 0xd0, 0x52, 0x69, 0x0e, 
  0xf7, 0x4a, 0x4c, 0xbb, 0x89, 0xc9, 0x8f, 0x13, 
  0x43, 0x69, 0x3e, 0xf7, 0xf6, 0xf4, 0xda, 0xcd, 
  0x52, 0x14, 0xae, 0x69, 0x74, 0xc1, 0x06, 0x28, 
  0x56, 0xa4, 0xcb, 0xec, 0x25, 0x34, 0x1a, 0x7d, 
  0xa2, 0x51, 0x06, 0x0d, 0x50, 0x46, 0x48, 0xa3, 
  0x56, 0xb0, 0x19, 0x51, 0xd0, 0x00, 0x97, 0xd1, 
  0xd0, 0x0c, 0xed, 0x00, 0x28, 0x4d, 0x66, 0x4e, 
  0xc7, 0xbd, 0xcc, 0x3a, 0xb0, 0xa9, 0x4e, 0x29, 
  0xf9, 0xba, 0xcc, 0xb3, 0x5a, 0x75, 0x59, 0x1c, 
  0x23, 0xa3, 0x1e, 0xd9, 0xfc, 0xba, 0x86, 0x37, 
  0x7d, 0x3f, 0x57, 0xae, 0xc2, 0x9e, 0x0f, 0x0d, 
  0xb5, 0xeb, 0xe3, 0x90, 0x25, 0xc2, 0x54, 0x6b, 
  0xc5, 0x6a, 0x23, 0xfd, 0x10, 0xa0, 0x11, 0x5e, 
  0x45, 0x39, 0xf2, 0x18, 0x30, 0x73, 0x55, 0x8a, 
  0xe5, 0x7f, 0x35, 0x2a, 0x2b, 0x19, 0x2f, 0x83, 
  0x65, 0x25, 0xd6, 0xb9, 0xb0, 0xed, 0xd7, 0xc6, 
  0x65, 0x99, 0x72, 0xca, 0x15, 0x53, 0x35, 0x54, 
  0x55, 0x0b, 0x53, 0x95, 0x42, 0x54, 0x89, 0x1a, 
  0x0a, 0x55, 0xb0, 0x6e, 0xf6, 0x3d, 0x4d, 0xc5, 
  0xa4, 0xe1, 0x7f, 0x1a, 0x94, 0x30, 0xbf, 0x73, 
  0xe9, 0x63, 0x82, 0xc0, 0xa0, 0xff, 0xa2, 0x74, 
  0xbc, 0x92, 0x75, 0x83, 0x18, 0x7b, 0xae, 0xb8, 
  0x9f, 0x09, 0x33, 0xa2, 0xab, 0x25, 0x82, 0xfc, 
  0xcd, 0x49, 0x75, 0x91, 0x3f, 0x60, 0x82, 0x8f, 
  0xc8, 0x03, 0xe8, 0x0b, 0xd4, 0x2c, 0x7e, 0x5f, 
  0xac, 0x0c, 0x64, 0x72, 0xec, 0xce, 0x46, 0x29, 
  0x07, 0x1b, 0xf7, 0x5d, 0x8a, 0x24, 0x8c, 0xe6, 
  0x0d, 0xb4, 0xf7, 0x57, 0xb6, 0x50, 0x6a, 0x93, 
  0x62, 0xbb, 0x7c, 0xce, 0x52, 0x97, 0x35, 0x4c, 
  0x9a, 0xc5, 0xdc, 0xa7, 0xc9, 0x7f, 0x9d, 0x32, 
  0xf6, 0x17, 0x5a, 0xe6, 0x35, 0xac, 0x53, 0xd4, 
  0xc6, 0x53, 0x6e, 0xa1, 0x56, 0x15, 0x66, 0x8d, 
  0x82, 0x34, 0xc2, 0x36, 0x10, 0x62, 0x59, 0x84, 
  0x5f, 0x1d, 0xe5, 0x0b, 0xc7, 0x0f, 0xf4, 0x35, 
  0xe2, 0x32, 0x63, 0x98, 0x17, 0xac, 0x0c, 0xba, 
  0xc5, 0x2d, 0x50, 0x5a, 0x9a, 0x35, 0x50, 0x49, 
  0x0d, 0x79, 0x65, 0xa0, 0xd2, 0xcb, 0x03, 0xcc, 
  0xbe, 0x8b, 0xda, 0xeb, 0xe8, 0x6e, 0x79, 0x0a, 
  0xdc, 0x5b, 0xe2, 0xbe, 0xaf, 0xe1, 0xda, 0x6e, 
  0x56, 0xd9, 0xd8, 0x52, 0x07, 0xaf, 0x64, 0x9d, 
  0x75, 0x06, 0xa7, 0xb6, 0x6e, 0x93, 0x8e, 0x3c, 
  0x41, 0x21, 0x7d, 0xef, 0xe8, 0xf9, 0x07, 0xe8, 
  0x1f, 0xf7, 0xff, 0x5e, 0xeb, 0xa5, 0xda, 0x4c, 
  0x04, 0x96, 0x3f, 0xb7, 0xd6, 0xb3, 0x86, 0xc9, 
  0xfb, 0xe4, 0xf3, 0xb0, 0x99, 0xf5, 0x6b, 0x6f, 
  0x49, 0x9b, 0x7b, 0x4b, 0x1b, 0xfd, 0xce, 0x30, 
  0x6c, 0xd5, 0x30, 0xfc, 0x4e, 0x30, 0xa4, 0xdf, 
  0x1a, 0x86, 0x85, 0x30, 0x24, 0x55, 0xd9, 0x29, 
  0x80, 0x32, 0x34, 0xda, 0x59, 0x0e, 0xf8, 0xfd, 
  0x7d, 0x6b, 0x4a, 0x33, 0x0e, 0x6c, 0xb1, 0x3b, 
  0x96, 0x69, 0x35, 0xd3, 0xf2, 0xbe, 0xa1, 0x87, 
  0x6f, 0x6b, 0xb8, 0x56, 0x82, 0x6b, 0xbb, 0x86, 
  0x6b, 0x31, 0x5c, 0x53, 0x2f, 0x4b, 0x9d, 0xac, 
  0x46, 0x6d, 0x21, 0x6a, 0xd3, 0x19, 0x3c, 0x85, 
  0x43, 0x54, 0x7a, 0x3a, 0xf3, 0xc4, 0x42, 0x99, 
  0x44, 0xc6, 0xd6, 0x73, 0x58, 0x38, 0xb0, 0xe5, 
  0x5c, 0x10, 0xe9, 0x8c, 0xa8, 0xcc, 0x26, 0xe2, 
  0x08, 0xd1, 0xda, 0x56, 0x79, 0x2e, 0xd1, 0xe7, 
  0x0c, 0xe6, 0x0a, 0xae, 0xa1, 0x5b, 0x09, 0xba, 
  0xfb, 0x35, 0x74, 0x8b, 0xa1, 0x6b, 0x30, 0x8c, 
  0xed, 0xcc, 0x7e, 0xa2, 0xb0, 0xc6, 0xee, 0x2b, 
  0x63, 0x37, 0x9b, 0xb2, 0xec, 0xcf, 0x35, 0x5c, 
  0x83, 0xb7, 0x12, 0x78, 0x0f, 0x6a, 0xf0, 0x16, 
  0x83, 0x37, 0xf7, 0xbe, 0x1a, 0xb8, 0xaf, 0x0c, 
  0xdc, 0x6e, 0xf6, 0xb0, 0x86, 0x6b, 0x25, 0xb8, 
  0xbe, 0xab, 0xe1, 0x5a, 0x0c, 0xd7, 0x6c, 0x8d, 
  0x0b, 0x75, 0xa0, 0xc6, 0x6a, 0x21, 0x56, 0xf3, 
  0x6f, 0xd6, 0x34, 0x9a, 0x59, 0xc4, 0xda, 0x35, 
  0x5f, 0xe1, 0x40, 0x0e, 0xe4, 0x53, 0xb6, 0xb4, 
  0x4d, 0x8f, 0xb9, 0xf1, 0xec, 0xc2, 0x40, 0x4b, 
  0xd5, 0x3b, 0x3f, 0xa6, 0xc7, 0xd1, 0x74, 0x75, 
  0xdd, 0x00, 0xcd, 0x18, 0x31, 0x02, 0x9f, 0x0f, 
  0x09, 0xf0, 0x16, 0xd9, 0x73, 0x6d, 0x6b, 0xd0, 
  0x89, 0x17, 0x00, 0xd3, 0xd0, 0xf5, 0xe5, 0x20, 
  0x63, 0xb5, 0xdf, 0xc9, 0x9a, 0x2e, 0xf2, 0x2c, 
  0x9d, 0xd2, 0xd5, 0x78, 0xaf, 0x84, 0xf7, 0xf7, 
  0x35, 0xde, 0x8b, 0xf1, 0xae, 0x46, 0x75, 0x15, 
  0xab, 0x0c, 0xee, 0xa8, 0x29, 0x1b, 0xe7, 0xcb, 
  0x01, 0x1f, 0x99, 0x48, 0x70, 0xb6, 0xfe, 0xd6, 
  0x0b, 0x24, 0xe5, 0xe1, 0xbc, 0xba, 0xc5, 0x23, 
  0xe8, 0xa1, 0xbf, 0x03, 0xe7, 0x8a, 0xc0, 0xbd, 
  0x03, 0xc7, 0x44, 0x38, 0x5b, 0xa3, 0xec, 0x74, 
  0x08, 0xbf, 0x35, 0x66, 0x2b, 0x61, 0xf6, 0x43, 
  0x8d, 0xd9, 0x62, 0xcc, 0xa2, 0x52, 0x52, 0xd5, 
  0xa8, 0x2d, 0x4f, 0xd2, 0x3a, 0x90, 0xe3, 0x2c, 
  0x03, 0xa7, 0xaa, 0x9a, 0x2e, 0x40, 0x7f, 0x96, 
  0x8a, 0x29, 0x73, 0x13, 0x30, 0x77, 0x9d, 0xce, 
  0xa9, 0x25, 0xa8, 0x01, 0x5a, 0x09, 0xa0, 0x3f, 
  0xd5, 0x00, 0x2d, 0x9d, 0x1a, 0xaa, 0x17, 0x1f, 
  0x6c, 0xf5, 0xe2, 0x83, 0x7a, 0x1a, 0x65, 0xe5, 
  0x34, 0x4a, 0xed, 0xe1, 0x5b, 0xed, 0xe1, 0xf5, 
  0x6c, 0xc3, 0xf2, 0x82, 0x65, 0xed, 0xde, 0x5b, 
  0xed, 0xde, 0x75, 0x81, 0x2f, 0x73, 0xef, 0x13, 
  0x5b, 0x9d, 0x9a, 0x6d, 0x82, 0x99, 0xd6, 0xaa, 
  0xb6, 0xa6, 0xcc, 0xf7, 0xa3, 0xbb, 0x59, 0x5d, 
  0x57, 0x2a, 0xaf, 0x2b, 0xd5, 0x11, 0x74, 0xab, 
  0x5d, 0xbb, 0x2e, 0xbf, 0xac, 0x5e, 0x8e, 0x50, 
  0xbb, 0xf8, 0x56, 0xbb, 0x78, 0x3d, 0x69, 0xbf, 
  0xac, 0xc2, 0x58, 0x3b, 0xf7, 0x56, 0x3b, 0xf7, 
  0xff, 0x67, 0x75, 0xae, 0x5c, 0xeb, 0x2b, 0xf6, 
  0xd0, 0x82, 0x3d, 0x32, 0x61, 0x5a, 0x43, 0x5e, 
  0x6f, 0xb3, 0xd7, 0xb7, 0xb0, 0x68, 0x6f, 0xc3, 
  0x3e, 0xaf, 0x75, 0x8a, 0xe4, 0xd3, 0x6d, 0x79, 
  0xd3, 0x53, 0x2f, 0x6c, 0x71, 0x3c, 0xdf, 0xca, 
  0x06, 0x43, 0x25, 0xc3, 0x67, 0x4b, 0xb7, 0xa7, 
  0xc7, 0x77, 0xf4, 0xb2, 0xc7, 0x2b, 0x7b, 0x43, 
  0xde, 0x97, 0x1d, 0xfb, 0xa2, 0x4b, 0x6d, 0x3f, 
  0x23, 0x99, 0xfa, 0x5c, 0xe6, 0x37, 0xd9, 0x14, 
  0x9b, 0xdd, 0xa8, 0x2f, 0xfc, 0xb2, 0xa2, 0xf9, 
  0xe1, 0xde, 0xf2, 0xf6, 0x37, 0xf6, 0x8e, 0xd7, 
  0xdb, 0xc9, 0xb9, 0xf1, 0xa6, 0xff, 0x35, 0xb7, 
  0xb6, 0x56, 0xda, 0xd6, 0xba, 0xfe, 0x5e, 0xce, 
  0x22, 0x05, 0x14, 0x0b, 0x5f, 0x65, 0x0b, 0xeb, 
  0xe6, 0xdb, 0x57, 0x37, 0xde, 0xba, 0x5a, 0x20, 
  0xea, 0x82, 0x98, 0x25, 0x87, 0xa1, 0x4c, 0x77, 
  0x98, 0x2b, 0x64, 0xce, 0x8a, 0x73, 0x40, 0xd2, 
  0x5d, 0xef, 0xdf, 0x9e, 0x8e, 0xf2, 0x8c, 0xff, 
  0x87, 0x3a, 0x1c, 0x44, 0xb0, 0x89, 0x4c, 0x8c, 
  0x9b, 0xce, 0x2d, 0x39, 0x1d, 0x8c, 0xfc, 0x17, 
  0x1f, 0xa2, 0xb1, 0x78, 0xb2, 0x80, 0x27, 0xa4, 
  0xc6, 0x35, 0x36, 0xf0, 0xe6, 0xf1, 0x76, 0x64, 
  0x1e, 0x9a, 0x29, 0xcb, 0x26, 0xae, 0x5e, 0xf5, 
  0x14, 0x80, 0xbf, 0x65, 0x13, 0xf1, 0x8b, 0x77, 
  0xfe, 0x17, 0x49, 0xaf, 0x8d, 0xf4, 0x1e, 0x56, 
  0xb1, 0x6e, 0x73, 0x0c, 0x6b, 0xfd, 0x18, 0x31, 
  0x6c, 0x23, 0x78, 0x55, 0x08, 0x62, 0xd4, 0x17, 
  0xd7, 0x8e, 0x3f, 0x96, 0xa3, 0xf1, 0xf5, 0x43, 
  0xdf, 0xd7, 0x9a, 0xf9, 0xea, 0xe1, 0x61, 0x86, 
  0xac, 0x26, 0x8d, 0xf8, 0x46, 0x68, 0x66, 0xd9, 
  0xf4, 0xeb, 0xbf, 0xed, 0xa8, 0x20, 0x96, 0x91, 
  0xa6, 0xde, 0xb4, 0x9c, 0xce, 0x73, 0xe8, 0x53, 
  0x26, 0x7e, 0x4e, 0x38, 0x7d, 0xc1, 0x62, 0xa3, 
  0xf3, 0x2e, 0x1c, 0xee, 0x3d, 0x3b, 0x65, 0xec, 
  0x7f, 0x03, 0x3c, 0x88, 0x8d, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x28, 0x75, 0x75, 0x61, 0x79, 0x29, 0x63, 
  0x6f, 0x6c, 0x6f, 0x72, 0x2d, 0x6d, 0x61, 0x6e, 
  0x61, 0x67, 0x65, 0x72, 0x2f, 0x00, 0x00, 0x00, 
  0x02, 0x00, 0x00, 0x00, 0x67, 0x6e, 0x6f, 0x6d, 
  0x65, 0x2f, 0x00, 0x00, 0x03, 0x00, 0x00, 0x00
} };

static GStaticResource static_resource = { gcm_resource_data.data, sizeof (gcm_resource_data.data), NULL, NULL, NULL };
extern GResource *gcm_get_resource (void);
GResource *gcm_get_resource (void)
{
  return g_static_resource_get_resource (&static_resource);
}
/*
  If G_HAS_CONSTRUCTORS is true then the compiler support *both* constructors and
  destructors, in a sane way, including e.g. on library unload. If not you're on
  your own.

  Some compilers need #pragma to handle this, which does not work with macros,
  so the way you need to use this is (for constructors):

  #ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
  #pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(my_constructor)
  #endif
  G_DEFINE_CONSTRUCTOR(my_constructor)
  static void my_constructor(void) {
   ...
  }

*/

#ifndef __GTK_DOC_IGNORE__

#if  __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 7)

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR(_func) static void __attribute__((constructor)) _func (void);
#define G_DEFINE_DESTRUCTOR(_func) static void __attribute__((destructor)) _func (void);

#elif defined (_MSC_VER) && (_MSC_VER >= 1500)
/* Visual studio 2008 and later has _Pragma */

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _wrapper(void) { _func(); return 0; } \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) static int (* _array ## _func)(void) = _func ## _wrapper;

#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _constructor(void) { atexit (_func); return 0; } \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) static int (* _array ## _func)(void) = _func ## _constructor;

#elif defined (_MSC_VER)

#define G_HAS_CONSTRUCTORS 1

/* Pre Visual studio 2008 must use #pragma section */
#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _wrapper(void) { _func(); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (*p)(void) = _func ## _wrapper;

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _constructor(void) { atexit (_func); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (* _array ## _func)(void) = _func ## _constructor;

#elif defined(__SUNPRO_C)

/* This is not tested, but i believe it should work, based on:
 * http://opensource.apple.com/source/OpenSSL098/OpenSSL098-35/src/fips/fips_premain.c
 */

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  init(_func)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void);

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  fini(_func)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void);

#else

/* constructors not supported for this compiler */

#endif

#endif /* __GTK_DOC_IGNORE__ */

#ifdef G_HAS_CONSTRUCTORS

#ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(resource_constructor)
#endif
G_DEFINE_CONSTRUCTOR(resource_constructor)
#ifdef G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(resource_destructor)
#endif
G_DEFINE_DESTRUCTOR(resource_destructor)

#else
#warning "Constructor not supported on this compiler, linking in resources will not work"
#endif

static void resource_constructor (void)
{
  g_static_resource_init (&static_resource);
}

static void resource_destructor (void)
{
  g_static_resource_fini (&static_resource);
}
